@@ -34,7 +34,7 @@ use File::Spec;
 #  Version information in a formate suitable for CPAN etc. Must be
 #  all on one line
 #
-$VERSION='2.036';
+$VERSION='2.038';
 
 
 #  Debug
@@ -416,53 +416,10 @@ sub filter {
 
 __END__
 
-=head1 Name
-
-WebDyne::Template - WebDyne extension module that implements document templating
-
-=head1 Description
-
-WebDyne::Template is a WebDyne extension module that implements document
-templating.  You can set templates for locations or sites, e.g.  menu
-sidebars, header, copyright information etc.  All psp documents within the
-scope of the location will then be embedded into the templates.
-
-Templates are WebDyne documents also - they can dynamically change (e.g.
-cascading menus, breadcrumb tracking etc.) based on any arbitrary criterea
-you determine.
-
-The target documents within the templating location do not have to be
-modified - the WebDyne::Template module will parse out head and body
-sections of requested documents and embed them into the location template as
-appropriate
-
-=head1 Documentation
-
-Information on configuration and usage is availeble from the WebDyne site,
-http://webdyne.org/ - or from a snapshot of current documentation in PDF
-format available in the WebDyne module source /doc directory.
-
-=head1 LICENSE and COPYRIGHT
-
-This file is part of WebDyne.
-
-This software is copyright (c) 2025 by Andrew Speer L<mailto:andrew.speer@isolutions.com.au>.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-Full license text is available at:
-
-L<http://dev.perl.org/licenses/>
-
-=head1 Author
-
-Andrew Speer, andrew@webdyne.org
-
-=head1 Bugs
-
-Please report any bugs or feature requests to "bug-webdyne-template at
-rt.cpan.org", or via
-http://rt.cpan.org/NoAuth/ReportBug.html?Queue=WebDyne-Template
+=begin markdown
 
 
+=end markdown
+
+
+=cut
